.. _image_overview:

*****
Image
*****

Images are mostly just the normal Wagtail Images. But they are
rendered using a `picture` tag supporting `srcset` and `sizes` attributes
for :ref:`responsive images <response_images_overview>`.
